package org.example.azapi;
import org.example.azapi.constants.AzDataTypeIdBoolean;

/**
 * AzAttributeValueBoolean contains a Java Boolean object that may
 * be used to generate the XACML #boolean DataType.
 * @author Rich
 */
public interface AzAttributeValueBoolean 
		extends AzAttributeValue<AzDataTypeIdBoolean, Boolean>{
	
	/**
	 * Set the value of this AzAttributeValueBoolean object
	 * with a Java Boolean object that can generate the string that
	 * can be used for the value of a XACML #boolean DataType.
	 * 
	 * @param booleanObject that can be used to generate 
	 * XACML #boolean DataType
	 */
	public void setValue(Boolean booleanObject);
	
	/**
	 * Return the Java Boolean object that is used by this 
	 * AzAttributeValueBoolean object to represent the 
	 * XACML #boolean DataType  
	 * 
	 * @return  a Java Boolean object that corresponds to the 
	 * XACML #boolean DataType
	 */
	public Boolean getValue();
	
	/**
	 * Return the Java String that can be used as the XACML #boolean
	 * DataType representation of the Java Boolean object contained in
	 * this AzAttributeValueBoolean object.
	 * 
	 * @return	a string that can be used as XACML #boolean 
	 * DataType content
	 * 
	 */
	public String toXacmlString();
}
