package org.example.azapi;
import org.example.azapi.constants.AzDataTypeIdHexBinary;

/**
 * AzAttributeValueHexBinary contains a Java byte[] object that may
 * be used to generate the XACML #hexBinary DataType.
 * @author Rich
 */
public interface AzAttributeValueHexBinary 
		extends AzAttributeValue<AzDataTypeIdHexBinary, AzDataByteArray>{
	
	/**
	 * Set the value of this AzAttributeValueHexBinary object
	 * with a Java AzDataByteArray object that can generate the 
	 * string that can be used for the value of a XACML 
	 * #hexBinary DataType.
	 * 
	 * @param azVal an azDataByteArray that can be used to generate 
	 * XACML #hexBinary DataType
	 */
	public void setValue(AzDataByteArray azVal);
	
	/**
	 * Return the Java AzDataByteArray object that contains the Java
	 * byte[] array that is used by this AzAttributeValueHexBinary 
	 * object to represent the XACML #hexBinary DataType  
	 * 
	 * @return  a Java azDataByteArray object that corresponds to the 
	 * XACML #hexBinary DataType
	 */
	public AzDataByteArray getValue();
	
	/**
	 * Return the Java String that can be used as the XACML #hexBinary
	 * DataType representation of the Java byte[] array, contained in
	 * the AzDataByteArray of this AzAttributeValueHexBinary object.
	 * 
	 * @return	a string that can be used as XACML #hexBinary 
	 * DataType content
	 * @see AzDataByteArray
	 */
	public String toXacmlString();
}

