package org.example.azapi;
import org.example.azapi.constants.AzDataTypeIdString;

/**
 * AzAttributeValueString contains a Java String object that may
 * be used to generate the XACML #string DataType.
 * @author Rich
 */
public interface AzAttributeValueString 
		extends AzAttributeValue<AzDataTypeIdString, String> {
	
	/**
	 * Set the value of this AzAttributeValueString object
	 * with a Java String object that can generate the string that
	 * can be used for the value of a XACML #string DataType.
	 * 
	 * @param azVal a string that can be used to generate XACML #string DataType
	 */
	public void setValue(String azVal);
	
	/**
	 * Return the Java String object that is used by this 
	 * AzAttributeValueString object to represent the 
	 * XACML #string DataType  
	 * 
	 * @return  a Java String object that corresponds to the 
	 * XACML #string DataType
	 */
	public String getValue();
	
	/**
	 * Return the Java String that can be used as the XACML #string
	 * DataType representation of the Java String object contained in
	 * this AzAttributeValueString object.
	 * 
	 * @return	a string that can be used as XACML #string 
	 * DataType content
	 */
	public String toXacmlString();
}
