package org.example.azapi;
import java.util.Date;

/**
 * Helper interface to collect the parameters necessary to create
 * the XACML #date, #time, #dateTime DataTypes.
 * <br>
 * Note: this interface is intended to replace the bare Date currently
 * used in the above XACML DataTypes, but has not yet been integrated.
 * @author rlevinson
 *
 */
public interface AzDataDateTime {
	
	/**
	 * Set the Date. 
	 * If not provided, then current date and time will be used and
	 * other parameters ignored.
	 * @param date
	 */
	public void setDate(Date date);
	
	/**
	 * Get the Date as is set in this object.
	 * 
	 */
	public Date getDate();
	
	/**
	 * Set the actual time zone that was used for the
	 * creation of the Date object as the offset to GMT in minutes.
	 * 
	 */
	public void setActualTimeZone(int timeZoneMinutes);
	
	/**
	 * Get the actual time zone offset in minutes
	 * 
	 */
	public int getActualTimeZone();
	
	/**
	 * Set the intended or expected time zone based on
	 * location where Date object was set.
	 * 
	 */
	public void setIntendedTimeZone(int timeZoneMinutes);
	
	/**
	 * Get the intended time zone
	 */
	public int getIntendedTimeZone();
	
	/**
	 * Set nanosecond offset
	 * 
	 */
	public void setNanoSecondOffset(int nanoSeconds);
	
	/**
	 * Get nanosecond offset
	 */
	public int getNanoSecondOffset();

}
