package org.example.azapi.constants;

public enum AzDataTypeIdRfc822Name implements AzDataTypeId {
	/** XACML DataType:  <b>urn:oasis:names:tc:xacml:1.0:data-type:rfc822Name</b>. 
	 * <br>The urn:oasis:names:tc:xacml:1.0:data-type:rfc822Name primitive type 
	 * represents an electronic mail address. The valid syntax for such a 
	 * name is described in IETF RFC 2821, Section 4.1.2, Command Argument 
	 * Syntax, under the term "Mailbox". 
	 * From rfc 2821:
	 * <pre>
	 *   Domain = (sub-domain 1*("." sub-domain)) / address-literal
	 *   sub-domain = Let-dig [Ldh-str]
	 *   address-literal = "[" IPv4-address-literal /
	 *                         IPv6-address-literal /
	 *                         General-address-literal "]"
	 *   Mailbox = Local-part "@" Domain
	 *   Local-part = Dot-string / Quoted-string
	 *   Dot-string = Atom *("." Atom)
	 *   Atom = 1*atext
	 *   Quoted-string = DQUOTE *qcontent DQUOTE
	 *   String = Atom / Quoted-string
	 * </pre>
	 * */ 
	AZ_DATATYPE_ID_RFC822NAME("urn:oasis:names:tc:xacml:1.0:data-type:rfc822Name");
	private final String azDataTypeId;

	AzDataTypeIdRfc822Name(String azDataTypeId) {
		this.azDataTypeId = azDataTypeId;
	}

	@Override
	public String toString() {
		return azDataTypeId;
	}
}