package org.example.azapi.constants;

public enum AzDataTypeIdX500Name implements AzDataTypeId {
	/** XACML DataType:  <b>urn:oasis:names:tc:xacml:1.0:data-type:x500Name</b>.
	 * <br>The urn:oasis:names:tc:xacml:1.0:data-type:x500Name 
	 * primitive type represents an ITU-T Rec. X.520 Distinguished 
	 * Name. 
	 * <br>The valid syntax for such a name is described in IETF 
	 * RFC 2253 "Lightweight Directory Access Protocol (v3): 
	 * UTF-8 String Representation of Distinguished Names"
	 * <p>
	 * For example the general nature of this syntax is described in
	 * the constructor for javax.security.auth.x500.X500Principal(String name): Creates an X500Principal 
	 * from a string representation of an X.500 distinguished name 
	 * <br>(ex: "CN=Duke, OU=JavaSoft, O=Sun Microsystems, C=US"). 
	 * <br>The distinguished name must be specified using the grammar defined 
	 * in RFC 1779 or RFC 2253 (either format is acceptable). 
	 */ 
	AZ_DATATYPE_ID_X500NAME("urn:oasis:names:tc:xacml:1.0:data-type:x500Name");
	private final String azDataTypeId;

	AzDataTypeIdX500Name(String azDataTypeId) {
		this.azDataTypeId = azDataTypeId;
	}

	@Override
	public String toString() {
		return azDataTypeId;
	}
}