package org.example.azapi.test;

import org.example.azapi.util.AzServiceFactory;
import org.example.azapi.constants.AzXacmlStrings;

import org.example.azapi.AzService;
import org.example.azapi.AzRequestContext;
import org.example.azapi.AzResourceActionAssociation;
import org.example.azapi.AzResourceActionAssociationId;
import org.example.azapi.AzResponseContext;
import org.example.azapi.AzResult;
import org.example.azapi.AzEntity;
import org.example.azapi.AzAttribute;
import org.example.azapi.AzAttributeValue;
import org.example.azapi.AzAttributeValueString;

import org.example.azapi.constants.AzCategoryId;
import org.example.azapi.constants.AzCategoryIdEnvironment;
import org.example.azapi.constants.AzCategoryIdSubjectAccess;
import org.example.azapi.constants.AzCategoryIdResource;
import org.example.azapi.constants.AzCategoryIdAction;
import org.example.azapi.constants.AzCategoryIdObligation;

import org.example.azapi.constants.AzDataTypeIdDateTime;
import org.example.azapi.constants.AzDataTypeIdString;

import java.util.HashSet;
import java.util.Set;
import java.util.Iterator;
import java.util.Date;

public class TestAzAPI implements AzXacmlStrings{
	
	// variable defns to provide "context" for test program:
	// defn: "container": manages "environment" and "issues" env attributes
	public final static String CONTAINER = "orcl-weblogic";   // [a03]
	// defn: "application": manages "resources" and "issues" resource attrs
	public final static String APPLICATION = "hr-application-01"; // [a04]	
	// test user; normally would be obtained from session info
	public final static String SAMPLE_SESSION_USER_NAME = "Joe User";
	public final static String SAMPLE_SESSION_AUTH_METHOD = "password";
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		// TODO Auto-generated method stub
		
		int testCounter = 0;
		
		// Get a reference to the authorization service:
		AzService azHandle = AzServiceFactory.getAzService();  // [a06]
		
		// Create an AzRequestContext:
		AzRequestContext azReqCtx = azHandle.createAzRequestContext();  // [a07]
		
		// Create an AzEnvironment entity and add an env attr:
		AzEntity<AzCategoryIdEnvironment> azEnv = 
			azReqCtx.createAzEntity(AzCategoryIdEnvironment.AZ_CATEGORY_ID_ENVIRONMENT);

		// Note: following line does not compile because of intended type
		// safety disallowing an AzEntity Resource to rcv requested Environment 
		// category:
		//AzEntity<AzCategoryIdResource> azEnv2 = 
		//	azReqCtx.createAzEntity(AzCategoryIdEnvironment.AZ_CATEGORY_ID_ENVIRONMENT);
		
		azEnv = azReqCtx.getAzEnvironment();
		if (azEnv == null) System.out.println("    TestAzAPI.azEnv is null");

		// Create a general purpose attribute value
		/*AzAttributeValueDateTime currentDateTimeValue = 
			azHandle.createAzAttributeValueDateTime();
		AzAttribute azAttr = azHandle.createAzAttribute(
				AzEnvironmentCategoryId.X_CATEGORY_ENVIRONMENT,  
				X_ATTR_ENV_CURRENT_DATE_TIME, CONTAINER, currentDateTimeValue);
		printAttributeData(azAttr, "env: curr-date-time 1");
		*/
		try {
			Thread.sleep(2000);
			System.out.println("Waited a second to get new time value\n");
		} catch (InterruptedException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		// Create an AzEnvironmentAttribute and add it to AzEnvironment
		//AzEnvironmentAttribute azEnvAttr =    // [a13]
		//	azEnv.createAndAddAzEnvironmentAttribute(
		//		X_ATTR_ENV_CURRENT_DATE_TIME, CONTAINER, 
		//		azEnv.createAzAttributeValueDateTime());
		AzAttribute<AzCategoryIdEnvironment> azEnvAttr =    // [a13]
			azEnv.createAzAttribute(
				CONTAINER, 
				X_ATTR_ENV_CURRENT_DATE_TIME, 
				azEnv.createAzAttributeValue(
					AzDataTypeIdDateTime.AZ_DATATYPE_ID_DATETIME, 
					azEnv.createAzDataDateTime(new Date(),0,0,0)));
					// Note: above is type safe - to protect against following
					// lines which use non-supported types.
					//AzDataTypeIdDateTime.AZ_DATATYPE_ID_DATETIME, new Date()));
					//AzDataTypeIdDateTime.AZ_DATATYPE_ID_DATETIME, new java.io.File("example")));
		
		System.out.println("    TestAzAPI.azEnv.idIdentityCounter = " + azEnv.getId());
		System.out.println("    TestAzAPI.azEnvAttr.attrId = " + azEnvAttr.getAttributeId());
		
		// Following does not compile because bad attributeValue parameters:
		//AzAttribute<AzCategoryIdEnvironment> azEnvAttrBad =    // [a13]
		//	azEnv.createAzAttribute(
		//		CONTAINER, 
		//		X_ATTR_ENV_CURRENT_DATE_TIME, 
		//		azEnv.createAzAttributeValue(
		//			AzDataTypeIdDateTime.AZ_DATATYPE_ID_DATETIME, "test"));
		//System.out.println("    TestAzAPI.azEnv.idIdentityCounter = " + azEnv.getId());
		//System.out.println("    TestAzAPI.azEnvAttrBad.attrId = " + azEnvAttrBad.getAttributeId());
		
		// Add environment object to AzRequestContext
		azReqCtx.addAzEntity(azEnv);  // [a15]
		
		// Get and print the attribute from the AzRequestContext:
		AzAttribute<AzCategoryIdEnvironment> azEnvCurrDateTime = 
			azReqCtx.getAzEnvironment().
					getAttributeByAttribId(X_ATTR_ENV_CURRENT_DATE_TIME);
		
		System.out.println("    TestAzAPI.azEnv.idIdentityCounter = " + azEnv.getId());

		Set<AzAttribute<AzCategoryIdEnvironment>> azEnvAttrSet = 
			azEnv.getAzAttributeSet();

		System.out.println("    TestAzAPI.azEnv.getAttributeSet()" +
				"\n\t 1st attr id = " + azEnvAttrSet.iterator().next().getAttributeId());
		printAttributeData(azEnvCurrDateTime, "env: curr-date-time 2");

		printAttributeData(
			azReqCtx.
				getAzEntity(AzCategoryIdEnvironment.AZ_CATEGORY_ID_ENVIRONMENT).
					getAttributeByAttribId(X_ATTR_ENV_CURRENT_DATE_TIME), 
				"env: curr-date-time 3");
		
		// Get a Subject Category and AzEntity for access-subject attributes
		AzCategoryIdSubjectAccess azSubjCat = 
			AzCategoryIdSubjectAccess.AZ_CATEGORY_ID_SUBJECT_ACCESS;

		AzEntity<AzCategoryIdSubjectAccess> accSubj = 
			azReqCtx.createAzEntity(
					AzCategoryIdSubjectAccess.AZ_CATEGORY_ID_SUBJECT_ACCESS);   // [a17]	
		
		// Three steps to create a subject attribute and add it to collection:
		AzAttributeValueString azAttrValueSubjId = 
			accSubj.createAzAttributeValue(
				AzDataTypeIdString.AZ_DATATYPE_ID_STRING,
				SAMPLE_SESSION_USER_NAME);

		AzAttribute<AzCategoryIdSubjectAccess> azAttrSubjectId = 
			accSubj.createAzAttribute(
					CONTAINER, 
					AzXacmlStrings.X_ATTR_SUBJECT_ID , 
					azAttrValueSubjId);

		System.out.println("TestAzApi azAttrSubjectId.getAttributeId: " + 
				azAttrSubjectId.getAttributeId());
		
		// One step to create a subject attribute and add it to collection: 
		accSubj.createAzAttribute(   // [a23]
				CONTAINER, 
				AzXacmlStrings.X_ATTR_SUBJECT_AUTHN_LOC_AUTHENTICATION_METHOD, 
				accSubj.createAzAttributeValue(
					AzDataTypeIdString.AZ_DATATYPE_ID_STRING, 
					SAMPLE_SESSION_AUTH_METHOD));
		
		// Add the Subject to the AzRequestContext:
		azReqCtx.addAzEntity(accSubj);  // [a26]
		
		// "Print" the attributes:
		AzAttribute<?> azAttr = null;
		azAttr = azReqCtx.getAzEntity(azSubjCat).
			getAttributeByAttribId(AzXacmlStrings.X_ATTR_SUBJECT_ID);
		printAttributeData(azAttr, "subject: subject-id");

		azAttr = azReqCtx.getAzEntity(azSubjCat).
			getAttributeByAttribId(
				AzXacmlStrings.X_ATTR_SUBJECT_AUTHN_LOC_AUTHENTICATION_METHOD);
		printAttributeData(azAttr, "subject: auth-method");
		
		// Get a Resource Category and AzEntity
		AzEntity<AzCategoryIdResource> azResource = 
			azReqCtx.createAzEntity(AzCategoryIdResource.AZ_CATEGORY_ID_RESOURCE); // [a31]
		
		// Create a resource id attribute:
		azResource.createAzAttribute(
			APPLICATION, 
			AzXacmlStrings.X_ATTR_RESOURCE_ID,
			azResource.createAzAttributeValue(
				AzDataTypeIdString.AZ_DATATYPE_ID_STRING, "file:C\\toplevel"));
		
		// Create six AzAction Category AzEntity objects
		AzEntity<AzCategoryIdAction> azActionA01 =          // [a35]
			azReqCtx.createAzEntity(AzCategoryIdAction.AZ_CATEGORY_ID_ACTION);
		AzEntity<AzCategoryIdAction> azActionA02 =          // [a36]
			azReqCtx.createAzEntity(AzCategoryIdAction.AZ_CATEGORY_ID_ACTION);
		AzEntity<AzCategoryIdAction> azActionA03 =          // [a36]
			azReqCtx.createAzEntity(AzCategoryIdAction.AZ_CATEGORY_ID_ACTION);
		AzEntity<AzCategoryIdAction> azActionA04 =          // [a36]
			azReqCtx.createAzEntity(AzCategoryIdAction.AZ_CATEGORY_ID_ACTION);
		AzEntity<AzCategoryIdAction> azActionA05 =          // [a36]
			azReqCtx.createAzEntity(AzCategoryIdAction.AZ_CATEGORY_ID_ACTION);
		AzEntity<AzCategoryIdAction> azActionA06 =          // [a36]
			azReqCtx.createAzEntity(AzCategoryIdAction.AZ_CATEGORY_ID_ACTION);
		
		AzCategoryId azCat = azActionA01.getAzCategoryId();
		System.out.println("azCat: class type = " + azCat.getClass().getName());
		
		azActionA01.createAzAttribute(APPLICATION,                     // [a38]
				AzXacmlStrings.X_ATTR_ACTION_ID,
				azActionA01.createAzAttributeValue(
					AzDataTypeIdString.AZ_DATATYPE_ID_STRING, "Read"));
		azActionA02.createAzAttribute(APPLICATION,                     // [a38]
				AzXacmlStrings.X_ATTR_ACTION_ID,
				azActionA02.createAzAttributeValue(
						AzDataTypeIdString.AZ_DATATYPE_ID_STRING, "Write"));
		azActionA03.createAzAttribute(APPLICATION,                     // [a38]
				AzXacmlStrings.X_ATTR_ACTION_ID,
				azActionA03.createAzAttributeValue(
						AzDataTypeIdString.AZ_DATATYPE_ID_STRING, "Delete"));
		azActionA04.createAzAttribute(APPLICATION,                     // [a38]
				AzXacmlStrings.X_ATTR_ACTION_ID,
				azActionA04.createAzAttributeValue(
						AzDataTypeIdString.AZ_DATATYPE_ID_STRING, "Read"));
		azActionA05.createAzAttribute(APPLICATION,                     // [a38]
				AzXacmlStrings.X_ATTR_ACTION_ID,
				azActionA05.createAzAttributeValue(
						AzDataTypeIdString.AZ_DATATYPE_ID_STRING, "Write"));
		azActionA06.createAzAttribute(APPLICATION,                     // [a38]
				AzXacmlStrings.X_ATTR_ACTION_ID,
				azActionA06.createAzAttributeValue(
						AzDataTypeIdString.AZ_DATATYPE_ID_STRING, "Read"));

		// Create set of actions
		Set<AzEntity<AzCategoryIdAction>> azActionSet = 
			new HashSet<AzEntity<AzCategoryIdAction>>();
		
		azActionSet.add(azActionA01);   // [a42]
		azActionSet.add(azActionA02);   // [a42]
		azActionSet.add(azActionA03);   // [a42]
		azActionSet.add(azActionA04);   // [a42]
		azActionSet.add(azActionA05);   // [a42]
		azActionSet.add(azActionA06);   // [a42]
		
		azReqCtx.addResourceActionAssociation(
				azResource, azActionSet);   // [a44]
		printAssociations(azReqCtx);

		AzResponseContext azRspCtx = azHandle.decide(azReqCtx); // [a47]
		AzResult azResult = null;
		Iterator<AzResult> itResults = azRspCtx.getResults().iterator();
		System.out.println("TestAzAPI: azRspCtx.hasNext() = " + 
				itResults.hasNext());
		while (itResults.hasNext()) {	 // [a50]
			testCounter++;
			System.out.println("\n\n***********************************" +
					             "\nTestAzAPI: Processing AzResult # " +
					testCounter + "\n***********************************");
			azResult = itResults.next();  // [a52]
			printResultData(azResult);	 // [a54], [a55]
			switch (azResult.getAzDecision()){
				case AZ_PERMIT: 
					System.out.println("  TestAzAPI: processing permit from the azResult");
					printObligations(azResult);
					break;
				case AZ_DENY:
					break;
				case AZ_NOTAPPLICABLE:
					break;
				case AZ_INDETERMINATE:
					switch (azResult.getAzStatusCode()) {
					case AZ_SYNTAX_ERROR:
						break;
					case AZ_PROCESSING_ERROR:
						break;
					case AZ_MISSING_ATTRIBUTE:
						System.out.println(
							"  TestAzAPI: processing missing attributes case from azResult");
						printMissingAttributes(azResult);
						break;
					}
			} // end switch			
		}

		// Test removeAll
		System.out.println("Set 6 before: " + azActionA06.getAzAttributeSet());
		azActionA06.getAzAttributeSet().removeAll(azActionA06.getAzAttributeSet()); 
		System.out.println("Set 6 after: " + azActionA06.getAzAttributeSet());

		System.out.println("Set 5 before: " + azActionA05.getAzAttributeSet());
		System.out.println("Attribute in set 5: " + azActionA05.getAttributeByAttribId(X_ATTR_ACTION_ID).getAttributeId());
		azActionA05.getAzAttributeSet().remove(azActionA05.getAttributeByAttribId(X_ATTR_ACTION_ID));
		System.out.println("Set 5 after: " + azActionA05.getAzAttributeSet());
			
	} // End of main()
	
	/**
	 * Some print modules to help test:
	 * @param azResult
	 */
	public static void printObligations(AzResult azResult){
		Iterator<AzEntity<AzCategoryIdObligation>> itOb = 
			azResult.getAzObligations().iterator();
		System.out.println("  TestAzAPI: itOb.hasNext() = " + 
			itOb.hasNext());
		while (itOb.hasNext()){
			AzEntity<AzCategoryIdObligation> azObligation = itOb.next();
			Iterator<AzAttribute<?>> itAttr = 
				azObligation.getAzAttributeMixedSet().iterator();
			System.out.println("  TestAzAPI: itAttr.hasNext() = " +
				itAttr.hasNext());
			while (itAttr.hasNext()){
				printAttributeData(itAttr.next(), 
					"Obligation attribute: ");
			}
		}		
	}
	public static void printMissingAttributes(AzResult azResult){
		Iterator<AzAttribute<?>> itMAD = 
			azResult.getAzStatusDetail().getAzAttributeMixedSet().iterator();
		System.out.println("  TestAzAPI: itMAD.hasNext() = " + 
			itMAD.hasNext());
		while (itMAD.hasNext()){
			AzAttribute<?> azMissingAttributeDetail = itMAD.next();
			printAttributeData(azMissingAttributeDetail, 
					"MissingAttributeDetail attribute: ");
		}		
	}
	
	public static void printResultData(AzResult azResult){
		System.out.println(
			"\nTestAzAPI: " +
			"\n\t azResult.getAzResourceActionAssociation.getCorrelationId: " +
					azResult.getAzResourceActionAssociation().getCorrelationId() +
				"\n\t azResult.getAzResourceActionAssociationId: " +
					"\n\t\t " + azResult.getAzResourceActionAssociation() +
				"\n\t azResult.getAzDecision: " +
					azResult.getAzDecision() +
				"\n\t azResult.getAzStatusCode: " +
					azResult.getAzStatusCode() +
				"\n\t azResult.getStatusMessage: " +
					"\n\t\t " + azResult.getStatusMessage());		
	}
	public static 
		<T extends Enum<T> & AzCategoryId> void printAttributeData(AzAttribute<T> azAttr, String info){
		String azCatIdClass = null;
		if (azAttr.getAzCategoryId() == null)
			azCatIdClass = "Null - no category in this attribute.";
		else
			azCatIdClass = azAttr.getAzCategoryId().getClass().getName();
		AzAttributeValue<?,?> azAttrVal = azAttr.getAzAttributeValue();
		System.out.println(
			"    TestAzAPI.printAttributeData: " + info +
			"\n\t azAttr.getAttributeId: " + azAttr.getAttributeId() +
			"\n\t azAttr.getClass: " + azAttr.getClass() +
			"\n\t azAttr.getCat: " + azAttr.getAzCategoryId() +
			"\n\t azAttr.getAzCategoryId.getClass: " + azCatIdClass +
			"\n\t azAttr.getAttrVal.getType: " + azAttrVal.getType() +
			"\n\t azAttr.getAttrVal.getValue: " + azAttrVal.getValue());
	}
	public static void printAssociations(AzRequestContext azReqCtx){
		AzResourceActionAssociationId azAssocId = null;
		System.out.println("TestAzApi.printAssociations: ");
		Iterator<AzResourceActionAssociation> it = azReqCtx.getAssociations().iterator();
		while (it.hasNext()){
			azAssocId = it.next().getAzResourceActionAssociationId();
			System.out.println("\t ResourceId: " + azAssocId.getResourceId() +
					"\t  ActionId: " + azAssocId.getActionId());
		}
	}
}
